@@ -358,7 +358,7 @@ class AutoFixtureBase(object):
                     max_value=field.MAX_BIGINT,
                     **kwargs)
         if isinstance(field, ImageField):
-            return generators.ImageGenerator(**kwargs)
+            return generators.ImageGenerator(storage=field.storage, **kwargs)
         for field_class, generator in self.field_to_generator.items():
             if isinstance(field, field_class):
                 return generator(**kwargs)
@@ -424,7 +424,12 @@ class AutoFixtureBase(object):
                 max_count=max_count,
                 **kwargs).generate()
 
-    def check_constrains(self, instance):
+    def check_constrains(self, *args, **kwargs):
+        raise TypeError(
+            'This method was renamed recently, since it contains a typo. '
+            'Please use the check_constraints method from now on.')
+
+    def check_constraints(self, instance):
         '''
         Return fieldnames which need recalculation.
         '''
@@ -475,7 +480,7 @@ class AutoFixtureBase(object):
         while process and tries > 0:
             for field in process:
                 self.process_field(instance, field)
-            process = self.check_constrains(instance)
+            process = self.check_constraints(instance)
             tries -= 1
         if tries == 0:
             raise CreateInstanceError(
